#!/bin/sh

check_if_started()
{
    app=$1

    pid=""
    cnt=""

    if [ -f "$pid_file" ] ; then
        pid=`cat $pid_file`
    fi

    if [ -f "$cnt_file" ] ; then
        cnt=`cat $cnt_file`
    fi

    if [ -z "$cnt" ] ; then
        cnt="999"
    fi

    if [ -n "$pid" -a $cnt -eq 0 ] ; then
        echo "Done. Process id (pid) is $pid."
    else
        echo "Failed. See $last_log and $app's log for details."
    fi
}

instance=""
log_file=""

if [ "$1" = "-l" ] ; then
    if [ -n "$2" ] ; then
        log_file=$2
    else
        log_file="instance_d_log.txt"
    fi
else
    if [ "$1" = "-i" ] ; then
        if [ -n "$2" ] ; then
            instance=$2
        else
            echo "Error: instance key is passed but instance is not defined. Exiting..."
            exit
        fi
    fi

    if [ "$3" = "-l" ] ; then
        if [ -n "$4" ] ; then
            log_file=$4
        else
            if [ -n "$instance" ] ; then
                log_file="instance_${instance}_log.txt"
            else
                log_file="instance_d_log.txt"
            fi
        fi
    fi
fi

if [ -n "$instance" ] ; then
    ins_test=`expr $instance + 1 - 1 2>/dev/null`
    if [ "$instance" != "$ins_test" ] ; then
        echo "Error: instance should be integer. Exiting..."
        exit        
    fi
fi

ins_text=""
ins_args=""
log_args=""
cnt_file=""
pid_file=""

if [ -n "$instance" ] ; then
    ins_text="Instance $instance"
    ins_args="-i $instance"
    pid_file=".instance_$instance.pid"
    cnt_file=".instance_${instance}_stopped.counter"
else
    ins_text="Default instance"
    pid_file=".instance_d.pid"
    cnt_file=".instance_d_stopped.counter"
fi

if [ -n "$log_file" ] ; then
    log_args="-l $log_file"
fi

dir="`pwd`"

last_log=".last_launch_log.txt"

echo "$ins_text will be started."

echo "===== Starting IRZ RSP Server ($ins_text) =====" | tee "$dir/$last_log"
cd "$dir"
cd remote-serialport-server
sh ./launch.sh $ins_args $log_args 1>>"$dir/$last_log" 2>&1 &
sleep 5s
check_if_started "remote-serialport-server"

echo "===== Starting IRZ Radar-24 Server ($ins_text) =====" | tee -a "$dir/$last_log"
cd "$dir"
cd radar24-server
sh ./launch.sh $ins_args $log_args 1>>"$dir/$last_log" 2>&1 &
sleep 5s
check_if_started "radar24-server"

echo "===== Starting IRZ Radar-24 JSON Adapter ($ins_text) =====" | tee -a "$dir/$last_log"
cd "$dir"
cd radar24-json-adapter
sh ./launch.sh $ins_args $log_args 1>>"$dir/$last_log" 2>&1 &
sleep 5s
check_if_started "radar24-json-adapter"
